==> mono_1.1.12.1.orig.tar.gz: mono-1.1.12.1/mcs/class/System.Web/System.Web.Management/WebApplicationInformation.cs <==
//
// System.Web.Management.WebApplicationInformation.cs
//
// Authors:
//	Duncan Mak (duncan@ximian.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
#if NET_2_0

using System;
using System.Web;

namespace System.Web.Management
{
        public class WebApplicationInformation
        {
                string application_domain, application_path, application_virtual_path, machine_name, trust_level;

                internal WebApplicationInformation ()
                {
                }
                
                public string ApplicationDomain {
                        get {
                                return application_domain;
                        }
                }

                public string ApplicationPath {
                        get {
                                return application_path;
                        }
                }

                public string ApplicationVirtualPath {
                        get {
                                return application_virtual_path;
                        }
                }

                public string MachineName {
                        get {
                                return machine_name;
                        }
                }

                public string TrustLevel {
                        get {
                                return trust_level;
                        }
                }

                public void FormatToString (WebEventFormatter formatter)
                {
                        throw new NotImplementedException ();
                }
                
                public override string ToString ()
                {
                        throw new NotImplementedException ();
                }
        }
}
#endif

==> mono_1.9.1+dfsg.orig.tar.gz: mono-1.9.1+dfsg/mcs/class/System.Web/System.Web.Management/WebApplicationInformation.cs <==
//
// System.Web.Management.WebApplicationInformation.cs
//
// Authors:
//	Duncan Mak (duncan@ximian.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
#if NET_2_0

using System;
using System.Web;

namespace System.Web.Management
{
        public sealed class WebApplicationInformation
        {
                string application_domain, application_path, application_virtual_path, machine_name, trust_level;

                internal WebApplicationInformation ()
                {
                }
                
                public string ApplicationDomain {
                        get {
                                return application_domain;
                        }
                }

                public string ApplicationPath {
                        get {
                                return application_path;
                        }
                }

                public string ApplicationVirtualPath {
                        get {
                                return application_virtual_path;
                        }
                }

                public string MachineName {
                        get {
                                return machine_name;
                        }
                }

                public string TrustLevel {
                        get {
                                return trust_level;
                        }
                }

                public void FormatToString (WebEventFormatter formatter)
                {
                        throw new NotImplementedException ();
                }
                
                public override string ToString ()
                {
                        throw new NotImplementedException ();
                }
        }
}
#endif
